==> bigdecimal-3.2.3.tar.gz: bigdecimal-3.2.3/test/bigdecimal/test_jruby.rb <==
# frozen_string_literal: false
require_relative 'helper'
require 'bigdecimal/math'

class TestJRuby < Test::Unit::TestCase
  # JRuby uses its own native BigDecimal implementation
  # but uses the same BigMath module as CRuby.
  # These are test to ensure BigMath works correctly with JRuby's BigDecimal.
  # Also run on CRuby to ensure compatibility.

  N = 20

  def test_sqrt
    sqrt2 = BigDecimal(2).sqrt(N)
    assert_in_delta(Math.sqrt(2), sqrt2)
    assert_in_delta(2, sqrt2 * sqrt2)
  end

  def test_exp
    assert_in_delta(Math.exp(2), BigMath.exp(BigDecimal(2), N))
    assert_in_delta(Math.exp(2), BigMath.exp(2, N))
    assert_in_delta(Math.exp(2.5), BigMath.exp(2.5, N))
    assert_in_delta(Math.exp(2.5), BigMath.exp(2.5r, N))
  end

  def test_log
    assert_in_delta(Math.log(2), BigMath.log(BigDecimal(2), N))
    assert_in_delta(Math.log(2), BigMath.log(2, N))
    assert_in_delta(Math.log(2.5), BigMath.log(2.5, N))
    assert_in_delta(Math.log(2.5), BigMath.log(2.5r, N))
  end

  def test_power
    x = BigDecimal(2)
    expected = 2 ** 2.5
    assert_in_delta(expected, x ** BigDecimal('2.5'))
    assert_in_delta(expected, x.sqrt(N) ** 5)
    # assert_in_delta(expected, x ** 2.5)
    assert_in_delta(expected, x ** 2.5r)
    assert_in_delta(expected, x.power(BigDecimal('2.5'), N))
    # assert_in_delta(expected, x.power(2.5, N))
    assert_in_delta(expected, x.sqrt(N).power(5, N))
    assert_in_delta(expected, x.power(2.5r, N))
  end

  def test_bigmath
    assert_in_delta(Math.sqrt(2), BigMath.sqrt(BigDecimal(2), N))
    assert_in_delta(Math.sin(1), BigMath.sin(BigDecimal(1), N))
    assert_in_delta(Math.cos(1), BigMath.cos(BigDecimal(1), N))
    assert_in_delta(Math.atan(1), BigMath.atan(BigDecimal(1), N))
    assert_in_delta(Math::PI, BigMath.PI(N))
    assert_in_delta(Math::E, BigMath.E(N))
  end
end

==> bigdecimal-3.3.1.tar.gz: bigdecimal-3.3.1/test/bigdecimal/test_jruby.rb <==
# frozen_string_literal: false
require_relative 'helper'
require 'bigdecimal/math'

class TestJRuby < Test::Unit::TestCase
  # JRuby uses its own native BigDecimal implementation
  # but uses the same BigMath module as CRuby.
  # These are test to ensure BigMath works correctly with JRuby's BigDecimal.
  # Also run on CRuby to ensure compatibility.

  N = 20

  def test_decimal_shift_polyfill
    assert_equal(BigDecimal('123.45e2'), BigDecimal('123.45')._decimal_shift(2))
    assert_equal(BigDecimal('123.45e-2'), BigDecimal('123.45')._decimal_shift(-2))
    assert_equal(BigDecimal('123.45e10000'), BigDecimal('123.45')._decimal_shift(10000))
    assert_equal(BigDecimal('123.45e-10000'), BigDecimal('123.45')._decimal_shift(-10000))
  end

  def test_sqrt
    sqrt2 = BigDecimal(2).sqrt(N)
    assert_in_delta(Math.sqrt(2), sqrt2)
    assert_in_delta(2, sqrt2 * sqrt2)
  end

  def test_exp
    assert_in_delta(Math.exp(2), BigMath.exp(BigDecimal(2), N))
    assert_in_delta(Math.exp(2), BigMath.exp(2, N))
    assert_in_delta(Math.exp(2.5), BigMath.exp(2.5, N))
    assert_in_delta(Math.exp(2.5), BigMath.exp(2.5r, N))
  end

  def test_log
    assert_in_delta(Math.log(2), BigMath.log(BigDecimal(2), N))
    assert_in_delta(Math.log(2), BigMath.log(2, N))
    assert_in_delta(Math.log(2.5), BigMath.log(2.5, N))
    assert_in_delta(Math.log(2.5), BigMath.log(2.5r, N))
  end

  def test_power
    x = BigDecimal(2)
    expected = 2 ** 2.5
    assert_in_delta(expected, x ** BigDecimal('2.5'))
    assert_in_delta(expected, x.sqrt(N) ** 5)
    assert_in_delta(expected, x ** 2.5)
    assert_in_delta(expected, x ** 2.5r)
    assert_in_delta(expected, x.power(BigDecimal('2.5'), N))
    assert_in_delta(expected, x.power(2.5, N))
    assert_in_delta(expected, x.sqrt(N).power(5, N))
    assert_in_delta(expected, x.power(2.5r, N))
  end

  def test_bigmath
    assert_in_delta(Math.sqrt(2), BigMath.sqrt(BigDecimal(2), N))
    assert_in_delta(Math.sin(1), BigMath.sin(BigDecimal(1), N))
    assert_in_delta(Math.cos(1), BigMath.cos(BigDecimal(1), N))
    assert_in_delta(Math.atan(1), BigMath.atan(BigDecimal(1), N))
    assert_in_delta(Math::PI, BigMath.PI(N))
    assert_in_delta(Math::E, BigMath.E(N))
  end
end
